# !/bin/bash
# Copy a file to UFS-910 using ftp
#
# Jochen Arndt <joe127@t-online.de>

# IP address of UFS-910
UFS_IP="192.168.178.19"
# Default destination directory
DESTDIR="/data"
# Use "-v" to be verbose or "" to be not verbose
#VERBOSE=""
VERBOSE="-v"

FTP=`which ftp`
if [ "$FTP" = "" ]; then
    echo "Error: ftp program not found."
    exit 1
fi

CHMOD=""
if [ "$1" = "-c" ]; then
    CHMOD="yes"
    shift
fi

if [ "$1" = "" -o "$1" = "-h" -o "$1" = "--help" ]; then
    echo "Usage: $0 [-c] <file-name> [dest-dir [dest-file]]"
    echo " -c        = change mode to 755 after copying"
    echo " file-name = file to be copied"
    echo " dest-dir  = destination directory (/data by default)"
    echo " dest-file = file name on target (basename of file-name by default)"
    exit 0
fi
if [ ! -e "$1" ]; then
    echo "Error: File '$1' not found."
    exit 1
fi
if [ ! -f "$1" ]; then
    echo "Error: '$1' is not a file."
    exit 1
fi

# Default name on destination host 
DESTNAME=`basename $1`
test -n "$2" && DESTDIR="$2"
test -n "$3" && DESTNAME="$3"

test -n "$CHMOD" && CHMOD="chmod 755 $DESTNAME"

"$FTP" "$VERBOSE" -u -n "$UFS_IP" <<-EOF
    user root kathrein
    binary
    cd $DESTDIR
    put $1 $DESTNAME
    $CHMOD
    quit
EOF
